@@ -167,9 +167,9 @@ class HTMLConverter:
                       lambda match : '<span style="page-break-after:always"> </span>'),
                      # Create header tags
                      (re.compile(r'<h2[^><]*?id=BookTitle[^><]*?(align=)*(?(1)(\w+))*[^><]*?>[^><]*?</h2>', re.IGNORECASE),
-                      lambda match : '<h1 id="BookTitle" align="{}">{}</h1>'.format(match.group(2) if match.group(2) else 'center', match.group(3))),
+                      lambda match : '<h1 id="BookTitle" align="{}">{}</h1>'.format(match.group(2) or 'center', match.group(3))),
                      (re.compile(r'<h2[^><]*?id=BookAuthor[^><]*?(align=)*(?(1)(\w+))*[^><]*?>[^><]*?</h2>', re.IGNORECASE),
-                      lambda match : '<h2 id="BookAuthor" align="{}">{}</h2>'.format(match.group(2) if match.group(2) else 'center', match.group(3))),
+                      lambda match : '<h2 id="BookAuthor" align="{}">{}</h2>'.format(match.group(2) or 'center', match.group(3))),
                      (re.compile(r'<span[^><]*?id=title[^><]*?>(.*?)</span>', re.IGNORECASE|re.DOTALL),
                       lambda match : f'<h2 class="title">{match.group(1)}</h2>'),
                      (re.compile(r'<span[^><]*?id=subtitle[^><]*?>(.*?)</span>', re.IGNORECASE|re.DOTALL),
@@ -683,7 +683,7 @@ class HTMLConverter:
             if not item.fragment and item.abspath in self.tops:
                 self.book.addTocEntry(ascii_text, self.tops[item.abspath])
             elif item.abspath:
-                url = item.abspath+(item.fragment if item.fragment else '')
+                url = item.abspath+(item.fragment or '')
                 if url in self.targets:
                     self.book.addTocEntry(ascii_text, self.targets[url])
 
@@ -1715,7 +1715,7 @@ class HTMLConverter:
                 if tag.has_attr('color'):
                     tag_css['color'] = tag['color']
                 self.process_children(tag, tag_css, tag_pseudo_css)
-            elif tagname in ['br']:
+            elif tagname == 'br':
                 self.line_break()
                 self.previous_text = '\n'
             elif tagname in ['hr', 'tr']:  # tr needed for nested tables
