@@ -1236,12 +1236,18 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
 
     def shutdown(self, write_settings=True):
         from time import monotonic
+
+        from calibre.utils.mdns import stop_server_with_joinable
+        wait_for_mdns_server_to_shutdown = stop_server_with_joinable()
         st = monotonic()
         timed_print('Shutdown starting...')
         self.shutting_down = True
+        if (dm := self.device_manager).is_running('smartdevice'):
+            dm.stop_plugin('smartdevice')
         if hasattr(self.library_view, 'connect_to_book_display_timer'):
             self.library_view.connect_to_book_display_timer.stop()
         self.shutdown_started.emit()
+        self.device_manager.shutdown_event.set()
         self.show_shutdown_message()
         timed_print('Shutdown message shown...')
         self.server_change_notification_timer.stop()
@@ -1283,7 +1289,6 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         self.listener.close()
         self.job_manager.server.close()
         self.job_manager.threaded_server.close()
-        self.device_manager.keep_going = False
         self.auto_adder.stop()
         timed_print('Various services shutdown')
         # Do not report any errors that happen after the shutdown
@@ -1329,12 +1334,22 @@ class Main(MainWindow, MainWindowMixin, DeviceMixin, EmailMixin,  # {{{
         wait_for_cleanup = cleanup_overseers()
         from calibre.live import async_stop_worker
         wait_for_stop = async_stop_worker()
-        timed_print('Waiting for overseers and live to shutdown')
+        timed_print('Waiting for overseers, mdns, and live to shutdown')
         self.istores.join()
         wait_for_cleanup()
         wait_for_stop()
+        wait_for_mdns_server_to_shutdown()
+        timed_print('Waiting for device manager to shutdown')
+        self.device_manager.join()
         self.shutdown_completed.emit()
         timed_print(f'Shutdown complete in {monotonic()-st:.2f}, quitting...')
+        if DEBUG:
+            import threading
+            threads = list(threading.enumerate())
+            if len(threads) > 1:
+                for thread in threads:
+                    if thread is not threading.main_thread():
+                        timed_print('Thread still alive:', thread)
         try:
             sys.stdout.flush()  # Make sure any buffered prints are written for debug mode
         except Exception:
